import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="reddit-tablify",
    version="1.0.1",
    description="Turn Python Dictionary into reddit table",
    long_description=README,
    long_description_content_type="text/markdown",
    author="Dangerforce",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["rtablify"],

)
